package com.flyfish.framework.approval.service;

import com.flyfish.framework.approval.domain.ApprovalDomain;
import com.flyfish.framework.approval.domain.record.ApproveRecord;
import com.flyfish.framework.domain.base.DomainService;
import com.flyfish.framework.service.BaseReactiveService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Mono;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * rest模块代理服务
 * 代理所有带审批的bean服务，用于模糊审批
 *
 * @author wangyu
 */
@Service
public class ModuleDelegateService {

    // 审批的服务们
    private Map<String, BaseReactiveService<ApprovalDomain>> approvalServices;

    @Autowired(required = false)
    public void setApprovalServices(List<BaseReactiveService<ApprovalDomain>> services) {
        this.approvalServices = services.stream()
                .collect(Collectors.toMap(DomainService::getCollectionName, s -> s));
    }

    /**
     * 获取服务
     *
     * @param module 模块
     * @return 结果
     */
    public BaseReactiveService<ApprovalDomain> getService(String module) {
        return approvalServices.get(module);
    }

    /**
     * 提交审批
     * @param record 记录
     * @return 结果
     */
    public Mono<ApprovalDomain> approval(ApproveRecord record) {
        getService(record.getModule()).getById(record.getDataId())
                .map(domain -> domain)
    }
}
